@@ -413,99 +413,103 @@ sub DESTROY {
 
 # {{{ sub AUTOLOAD 
 
-sub AUTOLOAD  {
-  my $self = shift;
-  
-  no strict 'refs';
+sub AUTOLOAD {
+    my $self = shift;
 
-  if ($AUTOLOAD =~ /.*::(\w+)/o &&  $self->_Accessible($1,'read') )  {
-    my $Attrib = $1;
-
-    *{$AUTOLOAD} = sub { return ($_[0]->_Value($Attrib))};
-    return($self->_Value($Attrib));
-  } elsif ($AUTOLOAD =~ /.*::[sS]et_?(\w+)/o) {
-
-    if ($self->_Accessible($1,'write')) {
-      my $Attrib = $1;
-
-      *{$AUTOLOAD} = sub {  
-        return ($_[0]->_Set(Field => $Attrib, Value => $_[1]))
-      };
-
-      my $Value = shift @_;
-      return($self->_Set(Field => $Attrib, Value => $Value));
+    no strict 'refs';
+    my $Attrib;
+    if ( $AUTOLOAD =~ /.*::(\w+)/o ) {
+        $Attrib = $1;
     } 
-
-    elsif ($self->_Accessible($1, 'read')) {
-      *{$AUTOLOAD} = sub {
-        return (0, 'Immutable field');
-      };
-      return(0, 'Immutable field');
-    } 
-    else { 
-      return(0, 'Nonexistant field?');
+    if ( $Attrib &&  $self->_Accessible( $Attrib, 'read' ) ) {
+        *{$AUTOLOAD} = sub { return ( $_[0]->_Value($Attrib) ) };
+        return ( $self->_Value($Attrib) );
     }
-  } elsif ($AUTOLOAD =~ /.*::(\w+?)_?[oO]bj$/o) {
-    if ($self->_Accessible($1,'object')) {
-      my $Attrib = $1;
-      *{$AUTOLOAD} = sub {
-      	my $s = shift;
-      	return $s->_Object(
-      			Field => $Attrib,
-      			Args => [@_],
-      		);
-      };
-      return $self->_Object( Field => $Attrib, Args => [@_] );
-    } else {
-      return(0, 'No object mapping for field');
+    elsif ( $AUTOLOAD =~ /.*::[sS]et_?(\w+)/o ) {
+            $Attrib = $1;
+
+        if ( $self->_Accessible( $Attrib, 'write' ) ) {
+
+            *{$AUTOLOAD} = sub {
+                return ( $_[0]->_Set( Field => $Attrib, Value => $_[1] ) );
+            };
+
+            my $Value = shift @_;
+            return ( $self->_Set( Field => $Attrib, Value => $Value ) );
+        }
+
+        elsif ( $self->_Accessible( $Attrib, 'read' ) ) {
+            *{$AUTOLOAD} = sub {
+                return ( 0, 'Immutable field' );
+            };
+            return ( 0, 'Immutable field' );
+        }
+        else {
+            return ( 0, 'Nonexistant field?' );
+        }
     }
-  }
+    elsif ( $AUTOLOAD =~ /.*::(\w+?)_?[oO]bj$/o ) {
+        $Attrib = $1;
+        if ( $self->_Accessible( $Attrib, 'object' ) ) {
+            *{$AUTOLOAD} = sub {
+                my $s = shift;
+                return $s->_Object(
+                    Field => $Attrib,
+                    Args  => [@_],
+                );
+            };
+            return $self->_Object( Field => $Attrib, Args => [@_] );
+        }
+        else {
+            return ( 0, 'No object mapping for field' );
+        }
+    }
 
+    #Previously, I checked for writability here. but I'm not sure that's the
+    #right idea. it breaks the ability to do ValidateQueue for a ticket
+    #on creation.
 
-  #Previously, I checked for writability here. but I'm not sure that's the
-  #right idea. it breaks the ability to do ValidateQueue for a ticket
-  #on creation.
+    elsif ( $AUTOLOAD =~ /.*::[vV]alidate_?(\w+)/o ) {
+        $Attrib = $1;
 
-  elsif ($AUTOLOAD =~ /.*::[vV]alidate_?(\w+)/o ) {
-    my $Attrib = $1;
+        *{$AUTOLOAD} = sub { return ( $_[0]->_Validate( $Attrib, $_[1] ) ) };
+        my $Value = shift @_;
+        return ( $self->_Validate( $Attrib, $Value ) );
+    }
 
-    *{$AUTOLOAD} = sub {  return ($_[0]->_Validate($Attrib, $_[1]))};
-    my $Value = shift @_;
-    return($self->_Validate($Attrib, $Value));
+    # TODO: if autoload = 0 or 1 _ then a combination of lowercase and _ chars,
+    # turn them into studlycapped phrases
+
+    else {
+        my ( $package, $filename, $line );
+        ( $package, $filename, $line ) = caller;
+
+        die "$AUTOLOAD Unimplemented in $package. ($filename line $line) \n";
     }
 
-  
-  # TODO: if autoload = 0 or 1 _ then a combination of lowercase and _ chars, 
-  # turn them into studlycapped phrases
-  
-  else {
-    my ($package, $filename, $line);
-    ($package, $filename, $line) = caller;
-    
-    die "$AUTOLOAD Unimplemented in $package. ($filename line $line) \n";
-  }
-  
 }
 
 # }}}
 
-# {{{ sub _Accessible 
+# {{{ sub _Accessible
 
-*_accessible = \&Accessible;
+=head2 _Accessible KEY MODE
+
+Private method.
+
+Returns undef unless C<KEY> is accessible in C<MODE> otherwise returns C<MODE> value
+
+=cut
+
+*_accessible = \&_Accessible;
 sub _Accessible {
     my $self = shift;
     my $attr = shift;
-    my $mode = lc(shift);
+    my $mode = lc(shift || '');
 
-    # @_ is the Accessible data from our subclass. Time to populate
-    # the accessible columns datastructure (but only if we're using
-    # something with the ancient API that predates ClassAccessible
-
-    #  return true if we can $mode $Attrib;
-    local ($^W) = 0;
     my $attribute = $self->_ClassAccessible(@_)->{$attr};
-    return 0 unless (defined $attribute && $attribute->{$mode});
-    return 1;
+    return unless defined $attribute;
+    return $attribute->{$mode};
 }
 
 # }}}
@@ -738,6 +742,22 @@ sub __Set {
     $args{'Table'}       = $self->Table();
     $args{'PrimaryKeys'} = { $self->PrimaryKeys() };
 
+    # The blob handling will destroy $args{'Value'}. But we assign
+    # that back to the object at the end. this works around that
+    my $unmunged_value = $args{'Value'};
+
+    unless ( $self->_Handle->KnowsBLOBs ) {
+        # Support for databases which don't deal with LOBs automatically
+        my $ca = $self->_ClassAccessible();
+        my $key = $args{'Column'};
+            if ( $ca->{$key}->{'type'} =~ /^(text|longtext|clob|blob|lob)$/i ) {
+                my $bhash = $self->_Handle->BLOBParams( $key, $ca->{$key}->{'type'} );
+                $bhash->{'value'} = $args{'Value'};
+                $args{'Value'} = $bhash;
+            }
+        }
+
+
     my $val = $self->_Handle->UpdateRecordValue(%args);
     unless ($val) {
         my $message = 
@@ -757,7 +777,7 @@ sub __Set {
         $self->Load( $self->Id );
     }
     else {
-        $self->{'values'}->{"$column"} = $args{'Value'};
+        $self->{'values'}->{"$column"} = $unmunged_value;
     }
     $ret->as_array( 1, "The new value has been set." );
     return ( $ret->return_value );
@@ -1141,13 +1161,11 @@ sub Create {
         }
     }
     unless ( $self->_Handle->KnowsBLOBs ) {
-
         # Support for databases which don't deal with LOBs automatically
         my $ca = $self->_ClassAccessible();
         foreach $key ( keys %attribs ) {
             if ( $ca->{$key}->{'type'} =~ /^(text|longtext|clob|blob|lob)$/i ) {
-                my $bhash =
-                  $self->_Handle->BLOBParams( $key, $ca->{$key}->{'type'} );
+                my $bhash = $self->_Handle->BLOBParams( $key, $ca->{$key}->{'type'} );
                 $bhash->{'value'} = $attribs{$key};
                 $attribs{$key} = $bhash;
             }
